@@ -1,7 +1,7 @@
-from .color import ColorScheme, ColorSchemes, supports_ansi  # noqa
+from .color import ColorScheme, ColorSchemes, supports_ansi, choose_color_scheme  # noqa
 from .core import iter_tb_lines  # noqa
 from .print import printing_tb, prints_tb, LoggerAsFile  # noqa
 from .override import override_print_tb  # noqa
 
 
-__version__ = '1.1.7.1'
+__version__ = '1.1.8'
